class PageNumMissing(BaseException):
    def __init__(self):
        self.message = "page number not found in note pages. Please correct the page num of preview page in note pages.."


class TextMappingNotFound(BaseException):
    def __init__(self):
        self.message = "Text mapping to its opf is not found. Please text pecha mapping.json in editable text repo"



from .notes import *
from .pagination_update import *
from .pecha import *
from .preprocess import *
from .preview_note_layer import *
from .reconstruction import *
from .save_text import *
from .texts import *
from .utils import *

__version__ = "0.1.59"
